==> estateplat-common-1.2.3-20180506.025257-76-sources.jar: cn/gtmap/estateplat/model/commodityHouse/contract/FcjyXjspfBaMmht.java <==
package cn.gtmap.estateplat.model.commodityHouse.contract;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/*
 * @author <a href="mailto:zhangguangguang@gtmap.cn">zhangguangguang</a>
 * @version 1.0, 2018/04/20
 * @description 新建商品房预售合同历史表
 */
@Table(name = "fcjy_xjspf_ba_mmht")
public class FcjyXjspfBaMmht {
    @Id
    private String htlsid;//主键
    private String htid;//合同表主键
    private Long htbh;//合同编号
    private String htzl;//合同坐落
    private String hid;//户ID
    private String xmid;//项目ID
    private String xmmc;//项目名称
    private String kfshtmbid;//开发商合同模板id
    private String xsfs;//销售方式
    private Date htqdrq;//合同签订日期
    private Date htqrrq;//合同确认日期
    private String htqrr;//合同确认人
    private Double jzmj;//建筑面积(平方米)
    private Double tnjzmj;//套内建筑面积(平方米)
    private Double htje;//合同金额
    private String htbz;//合同币种(币种字典表)
    private String jjfs;//计价方式
    private String fklx;//付款类型
    private String dkfs;//贷款方式
    private Date fksj;//付款时间
    private Double dj;//单价
    private String fdckfqymc;//房地产开发企业名称
    private Long fdckfqybh;//房地产开发企业编号
    private String fdckfqydh;//房地产开发企业电话
    private String fdckfqydz;//房地产开发企业地址
    private Date htcxrq;//合同撤销日期
    private String htcxqrr;//合同撤销确认人
    private String bz;//备注
    private String shzt;//审核状态（审核状态字典表）
    private String sfyx;//是否有效（有效性字典表）
    private String ckmm;
    private String yxs;//（YS：预售 XS：现售 ）
    private Date sxsj;//生效时间
    private Date basj;//备案时间
    private Integer dycs;//打印次数
    private Date lssj;//历史时间
    private Integer lscs;//历史次数

    public String getHtlsid() { return htlsid; }

    public void setHtlsid(String htlsid) { this.htlsid = htlsid; }

    public String getHtid() {
        return htid;
    }

    public void setHtid(String htid) {
        this.htid = htid;
    }

    public Long getHtbh() {
        return htbh;
    }

    public void setHtbh(Long htbh) {
        this.htbh = htbh;
    }

    public String getHtzl() {
        return htzl;
    }

    public void setHtzl(String htzl) {
        this.htzl = htzl;
    }

    public String getHid() {
        return hid;
    }

    public void setHid(String hid) {
        this.hid = hid;
    }

    public String getXmid() {
        return xmid;
    }

    public void setXmid(String xmid) {
        this.xmid = xmid;
    }

    public String getXmmc() {
        return xmmc;
    }

    public void setXmmc(String xmmc) {
        this.xmmc = xmmc;
    }

    public String getKfshtmbid() {
        return kfshtmbid;
    }

    public void setKfshtmbid(String kfshtmbid) {
        this.kfshtmbid = kfshtmbid;
    }

    public String getXsfs() {
        return xsfs;
    }

    public void setXsfs(String xsfs) {
        this.xsfs = xsfs;
    }

    public Date getHtqdrq() {
        return htqdrq;
    }

    public void setHtqdrq(Date htqdrq) {
        this.htqdrq = htqdrq;
    }

    public Date getHtqrrq() {
        return htqrrq;
    }

    public void setHtqrrq(Date htqrrq) {
        this.htqrrq = htqrrq;
    }

    public String getHtqrr() {
        return htqrr;
    }

    public void setHtqrr(String htqrr) {
        this.htqrr = htqrr;
    }

    public Double getJzmj() {
        return jzmj;
    }

    public void setJzmj(Double jzmj) {
        this.jzmj = jzmj;
    }

    public Double getTnjzmj() {
        return tnjzmj;
    }

    public void setTnjzmj(Double tnjzmj) {
        this.tnjzmj = tnjzmj;
    }

    public Double getHtje() {
        return htje;
    }

    public void setHtje(Double htje) {
        this.htje = htje;
    }

    public String getHtbz() {
        return htbz;
    }

    public void setHtbz(String htbz) {
        this.htbz = htbz;
    }

    public String getJjfs() {
        return jjfs;
    }

    public void setJjfs(String jjfs) {
        this.jjfs = jjfs;
    }

    public String getFklx() {
        return fklx;
    }

    public void setFklx(String fklx) {
        this.fklx = fklx;
    }

    public String getDkfs() {
        return dkfs;
    }

    public void setDkfs(String dkfs) {
        this.dkfs = dkfs;
    }

    public Date getFksj() {
        return fksj;
    }

    public void setFksj(Date fksj) {
        this.fksj = fksj;
    }

    public Double getDj() {
        return dj;
    }

    public void setDj(Double dj) {
        this.dj = dj;
    }

    public String getFdckfqymc() {
        return fdckfqymc;
    }

    public void setFdckfqymc(String fdckfqymc) {
        this.fdckfqymc = fdckfqymc;
    }

    public Long getFdckfqybh() {
        return fdckfqybh;
    }

    public void setFdckfqybh(Long fdckfqybh) {
        this.fdckfqybh = fdckfqybh;
    }

    public String getFdckfqydh() {
        return fdckfqydh;
    }

    public void setFdckfqydh(String fdckfqydh) {
        this.fdckfqydh = fdckfqydh;
    }

    public String getFdckfqydz() {
        return fdckfqydz;
    }

    public void setFdckfqydz(String fdckfqydz) {
        this.fdckfqydz = fdckfqydz;
    }

    public Date getHtcxrq() {
        return htcxrq;
    }

    public void setHtcxrq(Date htcxrq) {
        this.htcxrq = htcxrq;
    }

    public String getHtcxqrr() {
        return htcxqrr;
    }

    public void setHtcxqrr(String htcxqrr) {
        this.htcxqrr = htcxqrr;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getShzt() {
        return shzt;
    }

    public void setShzt(String shzt) {
        this.shzt = shzt;
    }

    public String getSfyx() {
        return sfyx;
    }

    public void setSfyx(String sfyx) {
        this.sfyx = sfyx;
    }

    public String getCkmm() {
        return ckmm;
    }

    public void setCkmm(String ckmm) {
        this.ckmm = ckmm;
    }

    public String getYxs() {
        return yxs;
    }

    public void setYxs(String yxs) {
        this.yxs = yxs;
    }

    public Date getSxsj() {
        return sxsj;
    }

    public void setSxsj(Date sxsj) {
        this.sxsj = sxsj;
    }

    public Date getBasj() {
        return basj;
    }

    public void setBasj(Date basj) {
        this.basj = basj;
    }

    public Integer getDycs() {
        return dycs;
    }

    public void setDycs(Integer dycs) {
        this.dycs = dycs;
    }

    public Date getLssj() { return lssj;}

    public void setLssj(Date lssj) { this.lssj = lssj;}

    public Integer getLscs() { return lscs; }

    public void setLscs(Integer lscs) { this.lscs = lscs; }
}

==> estateplat-common-1.2.3-20180515.074008-84-sources.jar: cn/gtmap/estateplat/model/commodityHouse/contract/FcjyXjspfBaMmht.java <==
package cn.gtmap.estateplat.model.commodityHouse.contract;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/*
 * @author <a href="mailto:zhangguangguang@gtmap.cn">zhangguangguang</a>
 * @version 1.0, 2018/04/20
 * @description 新建商品房预售合同历史表
 */
@Table(name = "fcjy_xjspf_ba_mmht")
public class FcjyXjspfBaMmht {
    @Id
    private String htlsid;//主键
    private String htid;//合同表主键
    private Long htbh;//合同编号
    private String htzl;//合同坐落
    private String hid;//户ID
    private String xmid;//项目ID
    private String xmmc;//项目名称
    private String kfshtmbid;//开发商合同模板id
    private String xsfs;//销售方式
    private Date htqdrq;//合同签订日期
    private Date htqrrq;//合同确认日期
    private String htqrr;//合同确认人
    private Double jzmj;//建筑面积(平方米)
    private Double tnjzmj;//套内建筑面积(平方米)
    private Double htje;//合同金额
    private String htbz;//合同币种(币种字典表)
    private String jjfs;//计价方式
    private String fklx;//付款类型
    private String dkfs;//贷款方式
    private Date fksj;//付款时间
    private Double dj;//单价
    private String fdckfqymc;//房地产开发企业名称
    private Long fdckfqybh;//房地产开发企业编号
    private String fdckfqydh;//房地产开发企业电话
    private String fdckfqydz;//房地产开发企业地址
    private Date htcxrq;//合同撤销日期
    private String htcxqrr;//合同撤销确认人
    private String bz;//备注
    private String shzt;//审核状态（审核状态字典表）
    private String sfyx;//是否有效（有效性字典表）
    private String ckmm;
    private String yxs;//（YS：预售 XS：现售 ）
    private Date sxsj;//生效时间
    private Date basj;//备案时间
    private Integer dycs;//打印次数
    private Date lssj;//历史时间
    private Integer lscs;//历史次数
    private String  yfdk;//以房抵款( 0：否  1：是)


    public String getHtlsid() { return htlsid; }

    public void setHtlsid(String htlsid) { this.htlsid = htlsid; }

    public String getHtid() {
        return htid;
    }

    public void setHtid(String htid) {
        this.htid = htid;
    }

    public Long getHtbh() {
        return htbh;
    }

    public void setHtbh(Long htbh) {
        this.htbh = htbh;
    }

    public String getHtzl() {
        return htzl;
    }

    public void setHtzl(String htzl) {
        this.htzl = htzl;
    }

    public String getHid() {
        return hid;
    }

    public void setHid(String hid) {
        this.hid = hid;
    }

    public String getXmid() {
        return xmid;
    }

    public void setXmid(String xmid) {
        this.xmid = xmid;
    }

    public String getXmmc() {
        return xmmc;
    }

    public void setXmmc(String xmmc) {
        this.xmmc = xmmc;
    }

    public String getKfshtmbid() {
        return kfshtmbid;
    }

    public void setKfshtmbid(String kfshtmbid) {
        this.kfshtmbid = kfshtmbid;
    }

    public String getXsfs() {
        return xsfs;
    }

    public void setXsfs(String xsfs) {
        this.xsfs = xsfs;
    }

    public Date getHtqdrq() {
        return htqdrq;
    }

    public void setHtqdrq(Date htqdrq) {
        this.htqdrq = htqdrq;
    }

    public Date getHtqrrq() {
        return htqrrq;
    }

    public void setHtqrrq(Date htqrrq) {
        this.htqrrq = htqrrq;
    }

    public String getHtqrr() {
        return htqrr;
    }

    public void setHtqrr(String htqrr) {
        this.htqrr = htqrr;
    }

    public Double getJzmj() {
        return jzmj;
    }

    public void setJzmj(Double jzmj) {
        this.jzmj = jzmj;
    }

    public Double getTnjzmj() {
        return tnjzmj;
    }

    public void setTnjzmj(Double tnjzmj) {
        this.tnjzmj = tnjzmj;
    }

    public Double getHtje() {
        return htje;
    }

    public void setHtje(Double htje) {
        this.htje = htje;
    }

    public String getHtbz() {
        return htbz;
    }

    public void setHtbz(String htbz) {
        this.htbz = htbz;
    }

    public String getJjfs() {
        return jjfs;
    }

    public void setJjfs(String jjfs) {
        this.jjfs = jjfs;
    }

    public String getFklx() {
        return fklx;
    }

    public void setFklx(String fklx) {
        this.fklx = fklx;
    }

    public String getDkfs() {
        return dkfs;
    }

    public void setDkfs(String dkfs) {
        this.dkfs = dkfs;
    }

    public Date getFksj() {
        return fksj;
    }

    public void setFksj(Date fksj) {
        this.fksj = fksj;
    }

    public Double getDj() {
        return dj;
    }

    public void setDj(Double dj) {
        this.dj = dj;
    }

    public String getFdckfqymc() {
        return fdckfqymc;
    }

    public void setFdckfqymc(String fdckfqymc) {
        this.fdckfqymc = fdckfqymc;
    }

    public Long getFdckfqybh() {
        return fdckfqybh;
    }

    public void setFdckfqybh(Long fdckfqybh) {
        this.fdckfqybh = fdckfqybh;
    }

    public String getFdckfqydh() {
        return fdckfqydh;
    }

    public void setFdckfqydh(String fdckfqydh) {
        this.fdckfqydh = fdckfqydh;
    }

    public String getFdckfqydz() {
        return fdckfqydz;
    }

    public void setFdckfqydz(String fdckfqydz) {
        this.fdckfqydz = fdckfqydz;
    }

    public Date getHtcxrq() {
        return htcxrq;
    }

    public void setHtcxrq(Date htcxrq) {
        this.htcxrq = htcxrq;
    }

    public String getHtcxqrr() {
        return htcxqrr;
    }

    public void setHtcxqrr(String htcxqrr) {
        this.htcxqrr = htcxqrr;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getShzt() {
        return shzt;
    }

    public void setShzt(String shzt) {
        this.shzt = shzt;
    }

    public String getSfyx() {
        return sfyx;
    }

    public void setSfyx(String sfyx) {
        this.sfyx = sfyx;
    }

    public String getCkmm() {
        return ckmm;
    }

    public void setCkmm(String ckmm) {
        this.ckmm = ckmm;
    }

    public String getYxs() {
        return yxs;
    }

    public void setYxs(String yxs) {
        this.yxs = yxs;
    }

    public Date getSxsj() {
        return sxsj;
    }

    public void setSxsj(Date sxsj) {
        this.sxsj = sxsj;
    }

    public Date getBasj() {
        return basj;
    }

    public void setBasj(Date basj) {
        this.basj = basj;
    }

    public Integer getDycs() {
        return dycs;
    }

    public void setDycs(Integer dycs) {
        this.dycs = dycs;
    }

    public Date getLssj() { return lssj;}

    public void setLssj(Date lssj) { this.lssj = lssj;}

    public Integer getLscs() { return lscs; }

    public void setLscs(Integer lscs) { this.lscs = lscs; }

    public String getYfdk() {
        return yfdk;
    }

    public void setYfdk(String yfdk) {
        this.yfdk = yfdk;
    }
}
